@@ -117,6 +117,14 @@ sub spam {
 	my $self = shift;
 	return $self->{session}->spam($self->{name});
 }
+sub approve {
+	my $self = shift;
+	return $self->{session}->approve($self->{name});
+}
+sub ignore_reports {
+	my $self = shift;
+	return $self->{session}->ignore_reports($self->{name});
+}
 sub edit {
     my ($self, $text) = @_;
 	croak 'This is not a self post' unless $self->{is_self};
@@ -172,13 +180,19 @@ Reddit::Client::Link
 
 Wraps a posted link or "self-post".
 
-=head1 SUBROUTINES/METHODS
+=head1 METHODS
 
 =over
 
-=item comments()
+=item get_comments
 
-Wraps C<Reddit::Client::get_comments>, implicitly providing the permalink parameter.
+=item remove
+
+=item spam
+
+=item approve
+
+=item ignore_reports
 
 =back
 
